package de.tu_darmstadt.tk.SmartHomeNetworkSim.control;

import de.tu_darmstadt.tk.SmartHomeNetworkSim.core.Model;
import de.tu_darmstadt.tk.SmartHomeNetworkSim.core.Port;
import de.tu_darmstadt.tk.SmartHomeNetworkSim.core.SimulationManager;
import de.tu_darmstadt.tk.SmartHomeNetworkSim.core.SmartDevice;

/**
 * Controller which enables configuration and manipulation of the simulation
 * 
 *
 * @author Andreas T. Meyer-Berg
 */
public class SimulationController {

	/**
	 * Main Controller which can be used internally
	 */
	@SuppressWarnings("unused")
	private Controller controller;
	/**
	 * Model which can be manipulated
	 */
	private Model model;
	
	/**
	 * Creates a new Simulation
	 * @param model
	 * @param controller
	 */
	public SimulationController(Model model, Controller controller) {
		this.model = model;
		this.controller = controller;
	}

	/**
	 * Reset Simulation 
	 * 
	 * @param controller TODO
	 * @param timestep
	 */
	public void resetSimulation(long timestep){
		for(SmartDevice d: model.getDevices())
			for(Port p:d.getPorts())
				if(p.getLastTrigger()>timestep)
					p.setLastTrigger(timestep);
	}

	/**
	 * Returns the Simulation Manager of the Program
	 * 
	 * @param controller TODO
	 * @return Simulation Manager
	 */
	public SimulationManager getSimulationManager() {
		return model.getSim();
	}
}
